using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel.Design;
using Microsoft.VisualStudio.Modeling;
using Microsoft.VisualStudio.Modeling.Shell;

using DTEUtils;

namespace ImTryin.ClassesLanguage
{
    internal partial class ClassesLanguageCommandSet
    {
        private const int ShowHideGripCommandId = 0x123;
        private const int AddEditAutomatBehaviorCommandId = 0x124;
        private const int ExportDiagramToImageCommandId = 0x125;

        protected override IList<MenuCommand> GetMenuCommands()
        {
            IList<MenuCommand> menuCommands = base.GetMenuCommands();

            DynamicStatusMenuCommand showHideGridCommand = new DynamicStatusMenuCommand(
                new EventHandler(OnStatusShowHideGrid),
                new EventHandler(OnMenuShowHideGrid),
                new CommandID(new Guid(Constants.ClassesLanguageCommandSetId), ShowHideGripCommandId)
                );
            menuCommands.Add(showHideGridCommand);

            DynamicStatusMenuCommand exportDiagramToImageCommand = new DynamicStatusMenuCommand(
                new EventHandler(OnStatusExportDiagramToImage),
                new EventHandler(OnMenuExportDiagramToImage),
                new CommandID(new Guid(Constants.ClassesLanguageCommandSetId), ExportDiagramToImageCommandId)
                );
            menuCommands.Add(exportDiagramToImageCommand);

            DynamicStatusMenuCommand addEditAutomatBehaviorCommand = new DynamicStatusMenuCommand(
                new EventHandler(OnStatusAddEditAutomatBehavior),
                new EventHandler(OnMenuAddEditAutomatBehavior),
                new CommandID(new Guid(Constants.ClassesLanguageCommandSetId), AddEditAutomatBehaviorCommandId)
                );
            menuCommands.Add(addEditAutomatBehaviorCommand);

            return menuCommands;
        }

        private void OnStatusShowHideGrid(object sender, EventArgs args)
        {
            MenuCommand command = sender as MenuCommand;
            if (command == null)
                return;
            command.Visible = command.Enabled = (IsDiagramSelected());
        }

        private void OnMenuShowHideGrid(object sender, EventArgs args)
        {
            CurrentDocView.CurrentDiagram.ShowGrid ^= true;
        }

        private void OnStatusExportDiagramToImage(object sender, EventArgs args)
        {
            MenuCommand command = sender as MenuCommand;
            if (command == null)
                return;
            command.Visible = command.Enabled = (IsDiagramSelected());
        }

        private void OnMenuExportDiagramToImage(object sender, EventArgs args)
        {
            CurrentDocView.CurrentDiagram.CreateMetafile(
                new object[] { CurrentDocView.CurrentDiagram }, CurrentDocView.DocData.FileName + ".emf");
        }


        private void OnStatusAddEditAutomatBehavior(object sender, EventArgs args)
        {
            MenuCommand command = sender as MenuCommand;
            if (command == null)
                return;
            ClassCompartmentShape classShape = SingleSelection as ClassCompartmentShape;
            command.Visible = command.Enabled = (classShape != null);
        }

        private void OnMenuAddEditAutomatBehavior(object sender, EventArgs args)
        {
            ClassCompartmentShape classShape = SingleSelection as ClassCompartmentShape;
            if (classShape == null)
                return;
            Class @class = (Class)classShape.ModelElement;
            StateMachineDTEUtils.EditProjectItem(@class.Name, @class.Store);
        }
    }

    //public static class Util
    //{
    //    public static T GetNthElement<T>(ICollection collection, int index)
    //    {
    //        if ((index < 0) || (index >= collection.Count))
    //            throw new ArgumentOutOfRangeException("index");
    //        int i = 0;
    //        object result = null;
    //        foreach (object o in collection)
    //        {
    //            if (i++ == index)
    //            {
    //                result = o;
    //                break;
    //            }
    //        }
    //        return (T) result;
    //    }
    //}
}
