using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using EnvDTE;
using Microsoft.VisualStudio.Modeling;

namespace DTEUtils
{
    public static class StateMachineDTEUtils
    {
        private static DTE GetDTE(Store store)
        {
            if (dte == null)
            {
                dte = (DTE)store.GetService(typeof(DTE));
            }
            return dte;
        }
        
        public static bool IsClassHasAutomat(string className, Store store)
        {
            InitializeDTE(store);
            return solutionItems.ContainsKey(GenerateAutomatFileName(className));
        }

        public static void EditProjectItem(string className, Store store)
        {
            ProjectItem itemForOpen = null;
            if (solutionItems.ContainsKey(GenerateAutomatFileName(className)))
            {
                itemForOpen = solutionItems[GenerateAutomatFileName(className)];
            }
            else
            {
                string tempFileName = Path.GetTempFileName();
                FileStream tempFileStream = File.Create(tempFileName);
                tempFileStream.Close();

                string fileName = GenerateAutomatFileName(className);
                Project activeProject = GetDTE(store).ActiveDocument.ProjectItem.ContainingProject;
                ProjectItem newItem = activeProject.ProjectItems.AddFromTemplate(tempFileName, fileName);
                newItem.Name = fileName;
                
                solutionItems[fileName] = newItem;
                
                itemForOpen = newItem;

                File.Delete(tempFileName);
            }
            itemForOpen.Open(Constants.vsViewKindPrimary);
        }

        private static string GenerateAutomatFileName(string className)
        {
            return className.ToLower() + ".statemachine";
        }

        private static DTE dte = null;
        private static Dictionary<string, ProjectItem> solutionItems = null;

        private static void InitializeDTE(Store store)
        {
            GetDTE(store);
            solutionItems = GetSolutionFileNames();
        }

        private static Dictionary<string, ProjectItem> GetSolutionFileNames()
        {
            Dictionary<string, ProjectItem> result = new Dictionary<string, ProjectItem>();

            Solution solution = dte.Solution;
            Projects projects = solution.Projects;
            foreach (Project project in projects)
            {
                ProjectItems projectItems = project.ProjectItems;
                foreach (ProjectItem item in projectItems)
                    GetProjectFiles(item, result);
            }

            return result;
        }

        private static void GetProjectFiles(ProjectItem item, Dictionary<string, ProjectItem> dictionary)
        {
            string name = item.Name.ToLower();
            dictionary[name] = item;
            ProjectItems items = item.ProjectItems;
            foreach (ProjectItem projectItem in items)
                GetProjectFiles(projectItem, dictionary);
        }
    }
}
