using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel.Design;
using Microsoft.VisualStudio.Modeling;
using Microsoft.VisualStudio.Modeling.Shell;

namespace ImTryin.StateMachineLanguage
{
    internal partial class StateMachineLanguageCommandSet
    {
        private const int ShowHideGripCommandId = 0x123;
        private const int ExportDiagramToImageCommandId = 0x125;

        protected override IList<MenuCommand> GetMenuCommands()
        {
            IList<MenuCommand> menuCommands = base.GetMenuCommands();

            DynamicStatusMenuCommand showHideGridCommand = new DynamicStatusMenuCommand(
                new EventHandler(OnStatusShowHideGrid),
                new EventHandler(OnMenuShowHideGrid),
                new CommandID(new Guid(Constants.StateMachineLanguageCommandSetId), ShowHideGripCommandId)
                );
            menuCommands.Add(showHideGridCommand);

            DynamicStatusMenuCommand exportDiagramToImageCommand = new DynamicStatusMenuCommand(
                new EventHandler(OnStatusExportDiagramToImage),
                new EventHandler(OnMenuExportDiagramToImage),
                new CommandID(new Guid(Constants.StateMachineLanguageCommandSetId), ExportDiagramToImageCommandId)
                );
            menuCommands.Add(exportDiagramToImageCommand);

            return menuCommands;
        }

        private void OnStatusShowHideGrid(object sender, EventArgs args)
        {
            MenuCommand command = sender as MenuCommand;
            if (command == null)
                return;
            command.Visible = command.Enabled = (IsDiagramSelected());
        }

        private void OnMenuShowHideGrid(object sender, EventArgs args)
        {
            CurrentDocView.CurrentDiagram.ShowGrid ^= true;
        }

        private void OnStatusExportDiagramToImage(object sender, EventArgs args)
        {
            MenuCommand command = sender as MenuCommand;
            if (command == null)
                return;
            command.Visible = command.Enabled = (IsDiagramSelected());
        }

        private void OnMenuExportDiagramToImage(object sender, EventArgs args)
        {
            CurrentDocView.CurrentDiagram.CreateMetafile(
                new object[] { CurrentDocView.CurrentDiagram }, CurrentDocView.DocData.FileName + ".emf");
        }
    }
}
